enum OpenRequest {
Open {
sender: GenericCallback<ConnectionMsg>,
db_name: String,
version: Option<u64>,
processed: bool,
pending_upgrade: Option<VersionUpgrade>,
pending_close: HashSet<Uuid>,
pending_versionchange: HashSet<Uuid>,
id: Uuid,
},
Delete {
sender: GenericCallback<BackendResult<u64>>,
_origin: ImmutableOrigin,
_db_name: String,
processed: bool,
id: Uuid,
},
}Expand description
https://w3c.github.io/IndexedDB/#request-open-request Used here to implement the https://w3c.github.io/IndexedDB/#connection-queue
Variants
Open
Fields

sender: GenericCallback<ConnectionMsg>The callback used to send a result to script.

version: Option<u64>Optionnaly, a requested db version. Note: when the open algorithm starts, this will be mutated and set to something as per the algo.

pending_upgrade: Option<VersionUpgrade>Optionally, a version pending upgrade.
Delete
Fields

sender: GenericCallback<BackendResult<u64>>The callback used to send a result to script.

_origin: ImmutableOriginThe origin of the request. TODO: storage key. Note: will be used when the full spec is implemented.
Implementations